<?php

if ( ! defined( 'ABSPATH' ) ) exit;
if ( ! is_admin() ) die;

/* Variablen für das Backend definieren */
define( 'WPAPPBOX_URL_PAYPAL', 'https://www.paypal.me/marcelismus' ); 
define( 'WPAPPBOX_URL_AMAZON', 'http://www.amazon.de/gp/registry/wishlist/1FC2DA2J8SZW7?tag=' . WPAPPBOX_AFFILIATE_AMAZON );


/**
* Registrierung der Einstellungen des Plugins
*
* @since   1.0.0
* @change  3.2.0
*/

function wpAppbox_pageInit() {
	$settings_page = add_options_page( WPAPPBOX_PLUGIN_NAME . ' ' . __('settings', 'wp-appbox') , WPAPPBOX_PLUGIN_NAME, 'manage_options', 'wp-appbox', 'wpAppbox_options_page' );
	add_action( "load-{$settings_page}", 'wpAppbox_loadSettingsPage' );
}


/**
* Initalisierung der Adminseite [deprecated]
*
* @since   1.0.0
* @change  3.2.0
*/

function wpAppbox_adminInit() {
}


/**
* Benachrichtigung im Admin-Panel anzeigen
*
* @since   4.0.0
* @change  4.0.18
*/

function wpAppbox_showAdminNotification() {
	if ( ( WPAPPBOX_PLUGIN_VERSION != get_option( 'wpAppbox_notifyLastV' ) ) && ( 'abc' == '123' ) ):
		?>
		<div class="notice notice-success is-dismissible">
			<p>
				🎉🎊 <strong><?php printf( esc_html__( 'WP-Appbox %1$s is here!', 'wp-appbox' ), WPAPPBOX_PLUGIN_VERSION ); ?> </strong>
				<?php printf( wp_kses( __( '<a href="%s" target="_blank">See here</a> what is new.', 'wp-appbox' ), array(  'a' => array( 'href' => array(), 'target' => array( '_blank') ) ) ), esc_url( ( get_locale() == 'de_DE' ) ? 'https://tchgdns.de/wp-appbox-4-0-0/' : 'https://translate.google.de/translate?hl=de&sl=de&tl=en&u=https%3A%2F%2Ftchgdns.de%2Fwp-appbox-4-0-0-co%2F' ) ); ?>
				<?php printf( wp_kses( __( 'If you like this plugin and find it useful, please <a href="%s" target="_blank">consider to rate</a> this plugin.', 'wp-appbox' ), array(  'a' => array( 'href' => array(), 'target' => array( '_blank') ) ) ), esc_url( 'https://wordpress.org/support/plugin/wp-appbox/reviews/' ) ); ?> :-)
			</p>
		</div>
		<?php
		update_option( 'wpAppbox_notifyLastV', WPAPPBOX_PLUGIN_VERSION, 'no' );
	endif;
}
add_action( 'admin_notices', 'wpAppbox_showAdminNotification' );


/**
* Anzeige der Apps im Cache im Dashboard-Glance-Widget
*
* @since   3.4.0
* @change  n/a
*/

function wpAppbox_counterInDashboard( $items = array() ) {
	if ( ! current_user_can('manage_options') ) {
		return( $items );
	}
	$countCachedApps = wpAppbox_countCachedApps();
	if ( $countCachedApps > 0 ) {
		echo( '<style>#dashboard_right_now .wp-appbox a:before { content: "\f108" !important; }</style>' );
		echo( '<li class="page-count wp-appbox"><a href="options-general.php?page=wp-appbox&amp;tab=cache-list">' . $countCachedApps . ' ' . _n( 'app in cache', 'apps in cache', $countCachedApps, 'wp-appbox' ) . '</a></li>' );
	}	
	//return( $items );
}
add_filter( 'dashboard_glance_items', 'wpAppbox_counterInDashboard', 10, 1 );


/**
* Ersetzt HTTP und HTTPS durch //
*
* @since   3.0.2
* @change  4.0.62
*
* @param   string  $currentTab  Aktuell ausgewählter Tab [optional]
*
* @output  HTML-Ausgabe der Tableiste Tableiste
*/

function wpAppbox_createTabs( $currentTab = 'info' ) {
	if ( isset($_GET['tab'] ) ) {
		$currentTab = $_GET['tab'];
	}
    $tabs = array(	
   		'info' => array( 'name' => __('Info', 'wp-appbox'), 'dashicon' => 'heart' ),
   		'output' => array( 'name' => __('Output', 'wp-appbox'), 'dashicon' => 'analytics' ), 
   		'cache' => array( 'name' => __('Cache', 'wp-appbox'), 'dashicon' => 'dashboard' ),  
   		'buttons' => array( 'name' => __('Editor-Buttons', 'wp-appbox'), 'dashicon' => 'editor-kitchensink' ), 
   		'storeurls' => array( 'name' => __('Store-URLs', 'wp-appbox'), 'dashicon' => 'admin-links' ), 
   		'affiliate' => array( 'name' => __('Affiliate IDs', 'wp-appbox'), 'dashicon' => 'chart-line' ),  
   		'advanced' => array( 'name' => __('Advanced', 'wp-appbox'), 'dashicon' => 'admin-tools' ),  
   		'help' => array( 'name' => __('Help', 'wp-appbox'), 'dashicon' => 'editor-help' )
    	);
    echo( '<h2 class="nav-tab-wrapper">' );
    foreach ( $tabs as $tab => $properties ) {
    	if ( 'cache-list' == $currentTab ) $currentTab = 'cache';
        $class = ( $tab == $currentTab ) ? ' nav-tab-active' : '';
        $dashicon = $properties['dashicon'];
        $name = $properties['name'];
        echo( "<a class='nav-tab$class dashicons-before dashicons-$dashicon' href='?page=wp-appbox&tab=$tab'> $name</a>" );
    }
    echo( '</h2>' );
}


/**
* Optionsseiten laden
*
* @since   1.0.0
* @change  3.2.0
*/

function wpAppbox_loadSettingsPage() {
	if ( isset( $_GET['tab'] ) && 'cachelist' == $_GET['tab'] ) {
		$args = array(
			'label' => __('Apps', 'wp-appbox'),
		  	'default' => 50,
		 	'option' => 'apps_per_page'
		);
		add_screen_option( 'per_page', $args) ;
	}
	if ( isset( $_POST["wp-appbox-settings-submit"]) && 'Y' == $_POST["wp-appbox-settings-submit"] ) {
		check_admin_referer( "wp-appbox-setting-page" );
		wpAppbox_saveSettings();
		$url_parameters = isset( $_GET['tab'] ) ? 'updated=true&tab=' . $_GET['tab'] : 'updated=true';
		wp_redirect( admin_url( "options-general.php?page=wp-appbox&$url_parameters" ) );
		exit;
	}
}


/**
* Anzahl der Einträge pro Seite in der Cache-Tabelle
*
* @since   2.0.0
* @change  3.2.0
*
* @param   string  $status   Status [WordPress]
* @param   string  $option   Angefragte Optionskey
* @param   string  $value    Angefragter Optionswert
* @return  string  $theURL   Umgewandelter App-Link
*/

function wpAppbox_setScreenOptions( $status, $option, $value ) {
	if ( 'apps_per_page' == $option ) {
  		return( $value );
  	}
}
add_filter( 'set-screen-option', 'wpAppbox_setScreenOptions', 10, 3 );


/**
* Einstellungen in "wp_options" speichern
*
* @since   1.0.0
* @change  4.0.19
*/

function wpAppbox_saveSettings() {
	global $wpAppbox_storeNames, $wpAppbox_optionsDefault;
	$tab = 'info';
	if ( isset( $_GET['tab'] ) ) {
		$tab = $_GET['tab'];
	}
	switch ( $tab ) {			
		case 'output':
	    	update_option( 'wpAppbox_downloadCaption', ( !empty( $_POST['wpAppbox_downloadCaption'] ) ? sanitize_text_field( $_POST['wpAppbox_downloadCaption'] ) : $wpAppbox_optionsDefault['downloadCaption'] ), 'no' );
			update_option( 'wpAppbox_nofollow', ( isset( $_POST['wpAppbox_nofollow'] ) ? true : false ), 'no' );
			update_option( 'wpAppbox_targetBlank', ( isset( $_POST['wpAppbox_targetBlank'] ) ? true : false ), 'no' );
			update_option( 'wpAppbox_screenshotTabs', ( isset( $_POST['wpAppbox_screenshotTabs'] ) ? true : false ), 'no' );
			update_option( 'wpAppbox_showRating', intval( $_POST['wpAppbox_showRating'] ), 'no' );
			update_option( 'wpAppbox_colorfulIcons', ( isset( $_POST['wpAppbox_colorfulIcons'] ) ? true : false ), 'no' );
			update_option( 'wpAppbox_defaultStyle', intval( $_POST['wpAppbox_defaultStyle'] ), 'no' );	 
			update_option( 'wpAppbox_replaceAppIcons', ( isset( $_POST['wpAppbox_replaceAppIcons'] ) ? true : false ), 'no' );	   		
			break;
		case 'cache':
			if ( TRUE == get_option('wpAppbox_blockMissing') && FALSE == $_POST['wpAppbox_blockMissing'] ) wpAppbox_resetBlockedQueries();
			update_option( 'wpAppbox_cacheTime', ( '' != intval( $_POST['wpAppbox_cacheTime'] ) ? intval( $_POST['wpAppbox_cacheTime'] ) : $wpAppbox_optionsDefault['cacheTime'] ), 'no' );
			update_option( 'wpAppbox_blockMissing', ( isset( $_POST['wpAppbox_blockMissing'] ) ? true : false ) );
			update_option( 'wpAppbox_blockMissingTime', ( '' != intval( $_POST['wpAppbox_blockMissingTime'] ) ? intval( $_POST['wpAppbox_blockMissingTime'] ) : $wpAppbox_optionsDefault['blockMissingTime'] ), 'no' );
			update_option( 'wpAppbox_cacheMode', ( !empty( $_POST['wpAppbox_cacheMode'] ) != '' ? sanitize_text_field( $_POST['wpAppbox_cacheMode'] ) : $wpAppbox_optionsDefault['cacheMode'] ), 'no' );
			update_option( 'wpAppbox_cronIntervall', ( '' != intval( $_POST['wpAppbox_cronIntervall'] ) ? intval( $_POST['wpAppbox_cronIntervall'] ) : $wpAppbox_optionsDefault['cronIntervall'] ), 'no' );
			update_option( 'wpAppbox_cronCount', ( '' != intval( $_POST['wpAppbox_cronCount'] ) ? intval( $_POST['wpAppbox_cronCount'] ) : $wpAppbox_optionsDefault['cronCount'] ), 'no' );
			update_option( 'wpAppbox_cachePlugin', ( !empty( $_POST['wpAppbox_cachePlugin'] ) != '' ? sanitize_text_field( $_POST['wpAppbox_cachePlugin'] ) : 0 ), 'no' );
			$imageCacheWAS = get_option( 'wpAppbox_imgCache' );
			if ( isset( $_POST['wpAppbox_imgCache'] ) && $_POST['wpAppbox_imgCache'] ) {
				if ( wpAppbox_imageCache::checkImageCache() ) 
					update_option( 'wpAppbox_imgCache', ( isset( $_POST['wpAppbox_imgCache'] ) ? true : false ), 'no' );
				else 
					set_transient( 'wpAppbox_imgCacheBlocked', true, 12 * HOUR_IN_SECONDS );
			} else {
				update_option( 'wpAppbox_imgCache', false, 'no' );
			}
			if ( $imageCacheWAS && !get_option( 'wpAppbox_imgCache' ) )
				$delete = wpAppbox_imageCache::deleteImageCache( true );
			if ( isset( $_POST['wpAppbox_imgCacheMode'] ) && is_array( $_POST['wpAppbox_imgCacheMode'] ) ) {
				update_option( 'wpAppbox_imgCacheMode',  array_map( 'strip_tags', $_POST['wpAppbox_imgCacheMode'] ), 'no');
			}
			else {
				delete_option( 'wpAppbox_imgCacheMode' );
			}
			update_option( 'wpAppbox_imgCacheDelay', ( isset( $_POST['wpAppbox_imgCacheDelay'] ) ? true : false ), 'no' );
			update_option( 'wpAppbox_imgCacheDelayTime', ( '' != intval( $_POST['wpAppbox_imgCacheDelayTime'] ) ? intval( $_POST['wpAppbox_imgCacheDelayTime'] ) : $wpAppbox_optionsDefault['imgCacheDelayTime'] ), 'no' );
			wpAppbox_setupCronCache();
	   		break;
    	case 'advanced':
	    	update_option( 'wpAppbox_amaAPIuse', ( isset( $_POST['wpAppbox_amaAPIuse'] ) ? true : false ), 'no' );
	    	update_option( 'wpAppbox_amaAPIsecretKey', ( !empty( $_POST['wpAppbox_amaAPIsecretKey'] ) ? base64_encode( strip_tags( trim( $_POST['wpAppbox_amaAPIsecretKey'] ) ) ) : '' ), 'no' );
	    	update_option( 'wpAppbox_amaAPIpublicKey', ( !empty( $_POST['wpAppbox_amaAPIpublicKey'] ) ? sanitize_text_field( trim( $_POST['wpAppbox_amaAPIpublicKey'] ) ) : '' ), 'no' );
	    	update_option( 'wpAppbox_affiliateAmazonID', ( !empty( $_POST['wpAppbox_affiliateAmazonID'] ) ? sanitize_text_field( trim( $_POST['wpAppbox_affiliateAmazonID'] ) ) : '' ), 'no' );
	    	update_option( 'wpAppbox_amaAPIregion', ( !empty( $_POST['wpAppbox_amaAPIregion'] ) ? sanitize_text_field( trim( $_POST['wpAppbox_amaAPIregion'] ) ) : '' ), 'no' );
	    	update_option( 'wpAppbox_autoLinks', ( isset( $_POST['wpAppbox_autoLinks'] ) ? true : false ), 'no' );
	    	update_option( 'wpAppbox_anonymizeLinks', ( isset( $_POST['wpAppbox_anonymizeLinks'] ) ? true : false ), 'no' );
	    	update_option( 'wpAppbox_disableDefer', ( isset( $_POST['wpAppbox_disableDefer'] ) ? true : false ), 'no' );
	    	update_option( 'wpAppbox_includeCSS', ( !empty( $_POST['wpAppbox_includeCSS'] ) ? sanitize_text_field( trim( $_POST['wpAppbox_includeCSS'] ) ) : '0' ), 'no' );
	    	update_option( 'wpAppbox_disableFonts', ( isset( $_POST['wpAppbox_disableFonts'] ) ? true : false ), 'no' );
	    	update_option( 'wpAppbox_curlTimeout', ( '' != intval( $_POST['wpAppbox_curlTimeout'] ) ? intval( $_POST['wpAppbox_curlTimeout'] ) : $wpAppbox_optionsDefault['curlTimeout'] ) );
    		update_option( 'wpAppbox_eOnlyAuthors', ( isset( $_POST['wpAppbox_eOnlyAuthors'] ) ? true : false ), 'no' );
    		update_option( 'wpAppbox_eOutput', ( !empty( $_POST['wpAppbox_eOutput'] ) ? sanitize_text_field( trim( $_POST['wpAppbox_eOutput'] ) ) : $wpAppbox_optionsDefault['eOutput'] ), 'no' );
    		update_option( 'wpAppbox_forceSSL', ( isset ( $_POST['wpAppbox_forceSSL'] ) ? true : false ), 'no' );
    		update_option( 'wpAppbox_imgProxy', ( isset ( $_POST['wpAppbox_imgProxy'] ) ? true : false ), 'no' );
	   		break;
	   	case 'buttons':
	   		update_option( 'wpAppbox_defaultButton', intval( $_POST['wpAppbox_defaultButton'] ) );
	   		foreach ( $wpAppbox_storeNames as $storeID => $storeName ):
			   	$key_buttonAppbox = "wpAppbox_buttonAppbox_$storeID";
				update_option( $key_buttonAppbox, ( isset( $_POST[$key_buttonAppbox] ) ? true : false ), 'no' );
			   	$key_buttonWYSIWYG = "wpAppbox_buttonWYSIWYG_$storeID";
				update_option( $key_buttonWYSIWYG, ( isset( $_POST[$key_buttonWYSIWYG] ) ? true : false ), 'no' );
			   	$key_buttonHTML = "wpAppbox_buttonHTML_$storeID";
				update_option( $key_buttonHTML, ( isset( $_POST[$key_buttonHTML] ) ? true : false ), 'no' );
			   	$key_buttonHidden = "wpAppbox_buttonHidden_$storeID";
				update_option( $key_buttonHidden, ( isset( $_POST[$key_buttonHidden] ) ? true : false ), 'no' );
	   		endforeach;
	   		break;
	   	case 'storeurls':
	   		foreach ( $wpAppbox_storeNames as $storeID => $storeName ):
		   		$key_storeURL = "wpAppbox_storeURL_$storeID";
		   		update_option( $key_storeURL, ( isset( $_POST[$key_storeURL] ) ? intval( $_POST[$key_storeURL] ) : '' ) );
		   		if ( isset( $_POST[$key_storeURL] ) && '0' == $_POST[$key_storeURL] ):
		   			$key_storeURL_URL = "wpAppbox_storeURL_URL_$storeID";
		   			update_option( $key_storeURL_URL, ( isset( $_POST[$key_storeURL_URL] ) ? sanitize_text_field( trim( $_POST[$key_storeURL_URL] ) ) : '' ), 'no' );
		   		endif;
	   		endforeach;
	   		break;
		case 'affiliate':
			update_option( 'wpAppbox_userAffiliate', ( isset( $_POST['wpAppbox_userAffiliate'] ) ? true : false ), 'no' );
			update_option( 'wpAppbox_affiliateAppleDev', ( isset( $_POST['wpAppbox_affiliateAppleDev'] ) ? true : false ), 'no' );
			update_option( 'wpAppbox_affiliateAppleID', ( !empty( $_POST['wpAppbox_affiliateAppleID'] ) ? sanitize_text_field( trim( $_POST['wpAppbox_affiliateAppleID'] ) ) : '' ), 'no' );
			update_option( 'wpAppbox_affiliateAmazonDev', ( isset( $_POST['wpAppbox_affiliateAmazonDev'] ) ? true : false ), 'no' );
			update_option( 'wpAppbox_affiliateAmazonID', ( !empty( $_POST['wpAppbox_affiliateAmazonID'] ) ? sanitize_text_field( trim( $_POST['wpAppbox_affiliateAmazonID'] ) ) : '' ), 'no' );
			update_option( 'wpAppbox_affiliateMicrosoftDev', ( isset( $_POST['wpAppbox_affiliateMicrosoftDev'] ) ? true : false ), 'no' );
			update_option( 'wpAppbox_affiliateMicrosoftProgram', $_POST['wpAppbox_affiliateMicrosoftProgram'], 'no' );
			update_option( 'wpAppbox_affiliateMicrosoftID', ( !empty( $_POST['wpAppbox_affiliateMicrosoftID'] ) ? sanitize_text_field( trim( $_POST['wpAppbox_affiliateMicrosoftID'] ) ) : '' ), 'no' );
		break;
	}
	update_option( 'wpAppbox_pluginVersion', WPAPPBOX_PLUGIN_VERSION );
}


/**
* Erzeugung und Ausgabe der Optionsseiten
*
* @since   1.0.0
* @change  4.0.31
*
* @output  HTML-Ausgabe der Optionsseiten
*/

function wpAppbox_options_page() {
	global $wpAppbox_storeNames, $wpAppbox_styleNames, $wpAppbox_storeStyles, $wpAppbox_storeURL_languages, $wpAppbox_storeURL, $wpAppbox_storeURL_noLanguages, $wpAppbox_amaAPIregions;
	if ( isset( $_GET['flushcache'] ) ) {
		$tab = 'cache'; 
	}
	?>
	<div class="wrap">
		<style>
			hr {
				margin-top: 10px !important;
				margin-bottom: 30px !important;
			}
			.wpa-error {
			}
			.wpa-infobox {
				display: block;
				background: #fff;
				border-left: 4px solid #fff;
				-webkit-box-shadow: 0 1px 1px 0 rgba(0, 0, 0, .1);
				box-shadow: 0 1px 1px 0 rgba(0, 0, 0, .1);
				margin: 20px 0 25px 0;
				padding: 10px 16px
			}
			.wpa-infobox.wpa-notice {
				border-left: 4px solid #ffba00;
			}
			.wpa-infobox.wpa-error {
				color: #b94a48;
				border-left-color: #dc3232
			}
			.wpa-infobox + h3 {
				padding-top: 8px;
			} 
			.wpa-infobox + .form-table {
				margin-top: -10px !important;
			} 
			.dashicons, .dashicons-before:before {
				line-height: 1.1 !important;
			}
		</style>
		<div id="icon-options-general" class="icon32">
			<br>
		</div>
		<h2><?php echo WPAPPBOX_PLUGIN_NAME; ?> (Version <?php echo WPAPPBOX_PLUGIN_VERSION; ?>)</h2>
		
		<?php if ( isset($_GET['flushcache'] ) ) {
			if( wpAppbox_clearCache() ) echo( '<div id="setting-error-settings_updated" class="updated settings-error is-dismissible"><p><strong>'.__( 'The cache was flushed successfully.', 'wp-appbox' ).'</strong></p></div>' );
			else echo( '<div id="setting-error-settings_updated" class="updated settings-error is-dismissible"><p><strong>'.__( 'The cache can not be emptied or there are no apps in the cache.', 'wp-appbox' ).'</strong></p></div>' );
		} ?>
		
		<?php if ( isset($_GET['flushimgcache'] ) ) {
			if( wpAppbox_imageCache::deleteImageCache() ) echo( '<div id="setting-error-settings_updated" class="updated settings-error is-dismissible"><p><strong>'.__( 'The image cache was flushed successfully.', 'wp-appbox' ).'</strong></p></div>' );
			else echo( '<div id="setting-error-settings_updated" class="updated settings-error is-dismissible"><p><strong>'.__( 'The image cache can not be emptied.', 'wp-appbox' ).'</strong></p></div>' );
		} ?>
		
		<?php if ( isset($_GET['resetdeprecated'] ) ) {
			if( wpAppbox_resetDeprecatedApps() ) echo( '<div id="setting-error-settings_updated" class="updated settings-error is-dismissible"><p><strong>'.__( 'Deprecated apps were successfully reset.', 'wp-appbox' ).'</strong></p></div>' );
			else echo( '<div id="setting-error-settings_updated" class="updated settings-error is-dismissible"><p><strong>'.__( 'Deprecated apps can not be resetted.', 'wp-appbox' ).'</strong></p></div>' );
		} ?>
		
		<?php if ( isset($_GET['resetblockedqueries'] ) ) {
			if( wpAppbox_resetBlockedQueries() ) echo( '<div id="setting-error-settings_updated" class="updated settings-error is-dismissible"><p><strong>'.__( 'Blocked queries were successfully reset.', 'wp-appbox' ).'</strong></p></div>' );
			else echo( '<div id="setting-error-settings_updated" class="updated settings-error is-dismissible"><p><strong>'.__( 'Blocked queries can not be resetted.', 'wp-appbox' ).'</strong></p></div>' );
		} ?>
		
		<?php if ( !wpAppbox_imageCache::checkImageCache() && ( get_option('wpAppbox_imgCache') || get_transient( 'wpAppbox_imgCacheBlocked' ) ) ): ?>
			<div class="notice notice-error is-dismissible">
				<p><span style="font-weight:bold;"><?php _e('Image cache is not active'); ?>: </span><?php echo( wpAppbox_imageCache::checkImageCache( true ) ); ?></p>
			</div>
			<?php delete_transient( 'wpAppbox_imgCacheBlocked' ); ?>
		<?php endif; ?>
		
		<?php  if( !wpAppbox_checkAmazonAPI() && get_option( 'wpAppbox_amaAPIuse' ) ) { ?>
			<div class="notice notice-error is-dismissible amaAPItr" <?php if( true != get_option( 'wpAppbox_amaAPIuse' ) ) { ?> style="display:none;"<?php } ?>>
				<p><strong>Amazon Product Advertising API: </strong><?php esc_html_e('Your public key, secret key or affiliate ID seems not correct. Please check or retry (maybe its just a server error).', 'wp-appbox'); ?> ;-)</p>
			</div>
		<?php } ?>
		
		<div class="widget" style="margin:15px 0;"><p style="margin:10px;">
			<a href="https://twitter.com/Marcelismus" target="_blank"><?php esc_html_e('Follow me on Twitter', 'wp-appbox'); ?></a> | <a href="<?php echo( ( get_locale() == 'de_DE' ) ? 'https://tchgdns.de/wp-appbox-app-badge-fuer-google-play-mac-app-store-windows-store-windows-phone-store-co/' : 'https://translate.google.de/translate?hl=de&sl=de&tl=en&u=https%3A%2F%2Ftchgdns.de%2Fwp-appbox-app-badge-fuer-google-play-mac-app-store-windows-store-windows-phone-store-co%2F' ); ?>" target="_blank"><?php esc_html_e('Visit the Plugin plage', 'wp-appbox'); ?></a> | <a href="http://wordpress.org/extend/plugins/wp-appbox/" target="_blank"><?php esc_html_e('Plugin at WordPress Directory', 'wp-appbox'); ?></a> | <a href="http://wordpress.org/plugins/wp-appbox/changelog/" target="_blank"><?php esc_html_e('Changelog', 'wp-appbox'); ?></a>
		</p></div>
		<div style="float: right;">
			<a href="<?php echo( WPAPPBOX_URL_PAYPAL ); ?>" class="button-primary" target="_blank" style="font-size: 12px; padding: 5px 6px; line-height: 13px !important; height: auto !important; margin-right: 6px; margin-top: 13px;"><?php esc_html_e('PayPal-Donation', 'wp-appbox'); ?></a>
			<a href="<?php echo( WPAPPBOX_URL_AMAZON ); ?>" class="button-primary" target="_blank" style="font-size: 12px; padding: 5px 6px; line-height: 13px !important; height: auto !important; margin-top: 13px;"><?php esc_html_e('Amazon Wishlist', 'wp-appbox'); ?></a>
		</div>
		<?php wpAppbox_createTabs(); ?>
		<form method="post" action="<?php admin_url( 'options-general.php?page=wp-appbox' ); ?>">
		<?php wp_nonce_field( "wp-appbox-setting-page" ); ?>
		<?php
			$tab = 'info';
			if ( isset( $_GET['tab'] ) ) {
				$tab = $_GET['tab'];
			}
			if ( isset( $tab ) ) {
				include_once( "admin-$tab.php" );
			} else {
				include_once( "admin-info.php" );
			}
		?>
		
		<?php if ( ( 'help' != $tab ) && ( 'info' != $tab ) && ( 'cache-list' != $tab ) ) { ?>
			<p class="submit" style="clear: both;">
			  	<input type="submit" name="Submit" class="button-primary" value="<?php esc_html_e('Save changes', 'wp-appbox'); ?>" />
				<input type="hidden" name="wp-appbox-settings-submit" value="Y" />
		   </p>
		<?php } ?>
		
	</form>
	</div>
<?php } ?>